==> deepin-camera_6.5.5.tar.xz: BUILD/src/translations/deepin-camera_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>A gravação de vídeo está em andamento. Fechar a janela?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Abrir pasta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Alternar câmera</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Você não tem permissão para operar esta pasta</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Pasta inválida</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Localização do arquivo</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Disparar</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Modo sequencial</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Atrasar temporizador</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Saída</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Formato de saída</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pçs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pçs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>O Câmera é um utilitário para capturar imagens e vídeos pela webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Arquivo não salvo</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Salvar em:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Vídeo:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Configurações da resolução</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Resolução:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotos:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Vídeos:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efeitos sonoros</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Modo câmera frontal</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Lanterna</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Interromper a gravação</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Exibir atalhos</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Interromper a captura de fotos</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu de contexto</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Capturar foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Gravar vídeo</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Interromper a captura de fotos</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Lanterna</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Ligado</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Desligado</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Atrasar captura</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nenhuma webcam encontrada</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>A webcam está em uso</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Interromper a gravação</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.20.tar.xz: BUILD/src/translations/deepin-camera_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>A gravação de vídeo está em andamento. Fechar janela?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Abrir pasta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Alternar câmeras</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Você não tem permissão para operar esta pasta</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Pasta inválida</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Localização do arquivo</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Capturar</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Modo sequencial</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Atrasar temporizador</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Saída</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Formato de saída</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 peças</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 peças</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>A Câmera é uma ferramenta de captura de imagem e vídeo que utiliza a câmera do seu PC ou webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Arquivo não salvo</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Salvar em:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Vídeo:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Configurações de resolução</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Resolução:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotos:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Vídeos:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efeitos sonoros</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Modo espelho</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Lanterna</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Linhas de grade</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>Linhas 1x1</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>Linhas 2x2</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Resolução máxima:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Interromper gravação</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Exibir atalhos</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Interromper captura de fotos</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu de contexto</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Capturar foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Gravar vídeo</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Interromper captura de fotos</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vívido</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Quente</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Frio</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Cinema</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinza</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>P&amp;B</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Lanterna</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Ligado</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Desligado</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Atrasar captura</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtros</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Exposição</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nenhuma webcam encontrada</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>A webcam está em uso</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Interromper gravação</translation>
    </message>
</context>
</TS>
